@@ -3,7 +3,7 @@ from typing import Iterable
 import logging
 
 from statina.adapter import StatinaAdapter
-from statina.crud.find.find import batch_samples
+from statina.crud.find.samples import batch_samples
 
 
 LOG = logging.getLogger(__name__)
